@@ -14,11 +14,10 @@ extensions = [
     ]
 
 intersphinx_mapping = {
-    'https://docs.python.org/3/': None,
-    'https://django.readthedocs.io/en/latest/': None,
-    'https://docs.pytest.org/en/latest/': None,
-    'https://sybil.readthedocs.io/en/latest/': None,
-    'https://zopecomponent.readthedocs.io/en/latest/': None,
+    'python': ('https://docs.python.org/3/', None),
+    'django': ('https://django.readthedocs.io/en/latest/', None),
+    'pytest': ('https://docs.pytest.org/en/latest/', None),
+    'sybil': ('https://sybil.readthedocs.io/en/latest/', None),
 }
 
 # General
@@ -41,3 +40,15 @@ latex_documents = [
 ]
 
 exclude_patterns = ['**/furo.js.LICENSE.txt']
+
+nitpicky = True
+nitpick_ignore = [
+    ('py:class', 'testfixtures.replace.R'),  # type var
+    ('py:class', 'module'),  # ModuleType not documented.
+    ('py:class', 'unittest.mock._Call'),  # No docstring.
+    ('py:class', 'tempfile.TemporaryFile'),  # not documented as a class so type annotation broken
+    ('py:class', 'constantly._constants.NamedConstant'),  # twisted logging constants
+    ('py:class', 'py.path.local'),  # deprecated and hard to reference
+    ('py:class', 'unittest.case.TestCase'),  # no docs, apparently
+    ('py:class', 'twisted.trial.unittest.TestCase'),  # twisted doesn't use sphinx
+]
