@@ -1,6 +1,6 @@
 from collections import defaultdict
 from logging import LogRecord
-from typing import List, Union, Tuple, Sequence, Callable, Any
+from typing import List, Union, Tuple, Sequence, Callable, Any, Optional
 import atexit
 import logging
 import warnings
@@ -54,6 +54,8 @@ class LogCapture(logging.Handler):
 
     #: The records captured by this :class:`LogCapture`.
     records: List[LogRecord]
+    #: The log level above which checks must be made for logged events.
+    ensure_checks_above: Optional[int]
 
     instances = set()
     atexit_setup = False
@@ -62,7 +64,7 @@ class LogCapture(logging.Handler):
 
     def __init__(
             self,
-            names: Union[str, Tuple[str]] = None,
+            names: Union[str, Tuple[str, ...]] = None,
             install: bool = True,
             level: int = 1,
             propagate: bool = None,
@@ -81,7 +83,6 @@ class LogCapture(logging.Handler):
         self.attributes = attributes
         self.recursive_check = recursive_check
         self.old = defaultdict(dict)
-        #: The log level above which checks must be made for logged events.
         if ensure_checks_above is None:
             self.ensure_checks_above = self.default_ensure_checks_above
         else:
@@ -99,6 +100,10 @@ class LogCapture(logging.Handler):
                 '%s' % ('\n'.join((str(i.names) for i in cls.instances)))
                 )
 
+    def __bool__(self) -> bool:
+        # Some logging internals check boolean rather than identity for handlers :-(r
+        return True
+
     def __len__(self):
         return len(self.records)
 
@@ -293,6 +298,15 @@ class LogCapture(logging.Handler):
         self.uninstall()
         self.ensure_checked()
 
+    def close(self):
+        super().close()
+        if self in self.instances:
+            raise AssertionError(
+                'LogCapture instance closed while still installed, '
+                'loggers captured:\n'
+                '%s' % ('\n'.join((str(i.names) for i in self.instances)))
+            )
+
 
 class LogCaptureForDecorator(LogCapture):
 
