@@ -1,7 +1,11 @@
 from contextlib import contextmanager
 from functools import wraps
+from typing import Union, Type, Callable
+
 from testfixtures import diff, compare
-from .compat import ClassType
+
+ExceptionOrType = Union[BaseException, Type[BaseException]]
+
 
 param_docs = """
 
@@ -25,7 +29,7 @@ param_docs = """
 """
 
 
-class ShouldRaise(object):
+class ShouldRaise:
     __doc__ = """
     This context manager is used to assert that an exception is raised
     within the context it is managing.
@@ -35,7 +39,7 @@ class ShouldRaise(object):
     #: Can be used to inspect specific attributes of the exception.
     raised = None
 
-    def __init__(self, exception=None, unless=False):
+    def __init__(self, exception: ExceptionOrType = None, unless: bool = False):
         self.exception = exception
         self.expected = not unless
 
@@ -48,7 +52,7 @@ class ShouldRaise(object):
         if self.expected:
             if self.exception:
                 if actual is not None:
-                    if isinstance(self.exception, (ClassType, type)):
+                    if isinstance(self.exception, type):
                         actual = type(actual)
                         if self.exception is not actual:
                             return False
@@ -74,11 +78,11 @@ class should_raise:
     raised.
     """ + param_docs
 
-    def __init__(self, exception=None, unless=None):
+    def __init__(self, exception: ExceptionOrType = None, unless: bool = None):
         self.exception = exception
         self.unless = unless
 
-    def __call__(self, target):
+    def __call__(self, target: Callable) -> Callable:
 
         @wraps(target)
         def _should_raise_wrapper(*args, **kw):
@@ -89,7 +93,7 @@ class should_raise:
 
 
 @contextmanager
-def ShouldAssert(expected_text):
+def ShouldAssert(expected_text: str):
     """
     A context manager to check that an :class:`AssertionError`
     is raised and its text is as expected.
