@@ -13,11 +13,7 @@ from testfixtures.utils import wrap
 from .rmtree import rmtree
 
 
-PathStrings = Union[str, Tuple[str]]
-
-
-if TYPE_CHECKING:
-    from py.path import local
+PathStrings = Union[str, Tuple[str, ...]]
 
 
 class TempDirectory:
@@ -40,6 +36,9 @@ class TempDirectory:
     :param encoding: A default encoding to use for :meth:`read` and
                      :meth:`write` operations when the ``encoding`` parameter
                      is not passed to those methods.
+
+    :param cwd: If ``True``, set the current working directory to be that of the temporary directory
+                when used as a decorator or context manager.
     """
 
     instances = set()
@@ -50,17 +49,20 @@ class TempDirectory:
 
     def __init__(
             self,
-            path: Union[str, Path, 'local'] = None,
+            path: Union[str, Path] = None,
             *,
             ignore: Sequence[str] = (),
             create: bool = None,
-            encoding: str = None
+            encoding: str = None,
+            cwd: bool = False,
     ):
         self.ignore = []
         for regex in ignore:
             self.ignore.append(compile(regex))
         self.path = str(path) if path else None
         self.encoding = encoding
+        self.cwd = cwd
+        self.original_cwd = None
         self.dont_remove = bool(path)
         if create or (path is None and create is None):
             self.create()
@@ -85,6 +87,9 @@ class TempDirectory:
         if not self.__class__.atexit_setup:
             atexit.register(self.atexit)
             self.__class__.atexit_setup = True
+        if self.cwd:
+            self.original_cwd = os.getcwd()
+            os.chdir(self.path)
         return self
 
     def cleanup(self) -> None:
@@ -93,6 +98,9 @@ class TempDirectory:
         This :class:`TempDirectory` cannot be used again unless
         :meth:`create` is called.
         """
+        if self.cwd:
+            os.chdir(self.original_cwd)
+            self.original_cwd = None
         if self.path and os.path.exists(self.path) and not self.dont_remove:
             rmtree(self.path)
             del self.path
@@ -293,6 +301,8 @@ class TempDirectory:
         encoding = encoding or self.encoding
         if encoding is not None:
             data = data.encode(encoding)
+        elif isinstance(data, str):
+            data = data.encode()
         with open(thepath, 'wb') as f:
             f.write(data)
         return thepath
@@ -331,19 +341,8 @@ class TempDirectory:
         """
         return Path(self.path if path is None else self._join(path))
 
-    def as_local(self, path: PathStrings = None) -> 'local':
-        """
-        Return the :class:`py.path.local` that corresponds to the path
-        relative to the temporary directory that is passed in.
-
-        :param path: The path to the file to create, which can be:
-
-                     * A tuple of strings.
-
-                     * A forward-slash separated string.
-        """
-        from py.path import local
-        return local(self.path if path is None else self._join(path))
+    def __truediv__(self, other: str) -> Path:
+        return self.as_path() / other
 
     def read(self, filepath: PathStrings, encoding: str = None) -> Union[bytes, str]:
         """
