@@ -1,13 +1,15 @@
 from textwrap import dedent
 
+import pytest
+
 from testfixtures import Comparison as C, ShouldRaise, should_raise
 from unittest import TestCase
 
-from ..compat import PY_37_PLUS
+from ..compat import PY_311_PLUS
 from ..shouldraise import ShouldAssert
 
 
-class TestShouldAssert(object):
+class TestShouldAssert:
 
     def test_no_exception(self):
         try:
@@ -37,7 +39,6 @@ class TestShouldAssert(object):
                 +assert False""")
 
 
-
 class TestShouldRaise(TestCase):
 
     def test_no_params(self):
@@ -54,10 +55,7 @@ class TestShouldRaise(TestCase):
     def test_wrong_exception(self):
         def to_test():
             raise ValueError('bar')
-        if PY_37_PLUS:
-            expected = "ValueError('foo') (expected) != ValueError('bar') (raised)"
-        else:
-            expected = "ValueError('foo',) (expected) != ValueError('bar',) (raised)"
+        expected = "ValueError('foo') (expected) != ValueError('bar') (raised)"
         with ShouldAssert(expected):
             should_raise(ValueError('foo'))(to_test)()
 
@@ -176,10 +174,7 @@ class TestShouldRaise(TestCase):
             raise ValueError('foo bar')
 
     def test_with_exception_supplied_wrong_args(self):
-        if PY_37_PLUS:
-            expected = "ValueError('foo') (expected) != ValueError('bar') (raised)"
-        else:
-            expected = "ValueError('foo',) (expected) != ValueError('bar',) (raised)"
+        expected = "ValueError('foo') (expected) != ValueError('bar') (raised)"
         with ShouldAssert(expected):
             with ShouldRaise(ValueError('foo')):
                 raise ValueError('bar')
@@ -189,10 +184,7 @@ class TestShouldRaise(TestCase):
             raise ValueError('foo bar')
 
     def test_with_no_exception_when_expected(self):
-        if PY_37_PLUS:
-            expected = "ValueError('foo') (expected) != None (raised)"
-        else:
-            expected = "ValueError('foo',) (expected) != None (raised)"
+        expected = "ValueError('foo') (expected) != None (raised)"
         with ShouldAssert(expected):
             with ShouldRaise(ValueError('foo')):
                 pass
@@ -311,4 +303,26 @@ class TestShouldRaise(TestCase):
             with ShouldRaise(MessageError('foo')):
                 raise MessageError('foo', None)
 
+    @pytest.mark.skipif(not PY_311_PLUS, reason="requires python3.11 or higher")
+    def test_exception_group_okay(self):
+        with ShouldRaise(ExceptionGroup('foo', [Exception('bar')])):
+            raise ExceptionGroup('foo', [Exception('bar')])
+
+    @pytest.mark.skipif(not PY_311_PLUS, reason="requires python3.11 or higher")
+    def test_exception_group_different(self):
+        with ShouldAssert(
+                "exception group not as expected:\n\n"
+                "While comparing msg: 'fob' (expected) != 'foo' (raised)\n\n"
+                "While comparing excs: sequence not as expected:\n\n"
+                "same:\n"
+                "[]\n\n"
+                "expected:\n"
+                "[Exception('baz')]\n\n"
+                "raised:\n"
+                "[Exception('bar')]\n\n"
+                "While comparing excs[0]: "
+                "Exception('baz') (expected) != Exception('bar') (raised)"
+        ):
+            with ShouldRaise(ExceptionGroup('fob', [Exception('baz')])):
+                raise ExceptionGroup('foo', [Exception('bar')])
 
