@@ -7,34 +7,34 @@ from unittest import TestCase
 class Tests(TestCase):
 
     def test_equal_yes(self):
-        self.assertTrue('on 40220' == S('on \d+'))
+        self.assertTrue('on 40220' == S(r'on \d+'))
 
     def test_equal_no(self):
-        self.assertFalse('on xxx' == S('on \d+'))
+        self.assertFalse('on xxx' == S(r'on \d+'))
 
     def test_not_equal_yes(self):
-        self.assertFalse('on 40220' != S('on \d+'))
+        self.assertFalse('on 40220' != S(r'on \d+'))
 
     def test_not_equal_no(self):
-        self.assertTrue('on xxx' != S('on \d+'))
+        self.assertTrue('on xxx' != S(r'on \d+'))
 
     def test_comp_in_sequence(self):
         self.assertTrue((
             1, 2, 'on 40220'
             ) == (
-            1, 2, S('on \d+')
+            1, 2, S(r'on \d+')
             ))
 
     def test_not_string(self):
-        self.assertFalse(40220 == S('on \d+'))
+        self.assertFalse(40220 == S(r'on \d+'))
 
     def test_repr(self):
         compare('<S:on \\d+>',
-                repr(S('on \d+')))
+                repr(S(r'on \d+')))
 
     def test_str(self):
         compare('<S:on \\d+>',
-                str(S('on \d+')))
+                str(S(r'on \d+')))
 
     def test_sort(self):
         a = S('a')
