@@ -4,8 +4,6 @@ from tempfile import mkdtemp
 from unittest import TestCase
 from warnings import catch_warnings
 
-from py.path import local
-
 from testfixtures.mock import Mock
 
 from testfixtures import (
@@ -249,10 +247,10 @@ class TempDirectoryTests(TestCase):
             with open(os.path.join(d.path, 'test.file'), 'rb') as f:
                 compare(f.read(), b'\xc2\xa3')
 
-    def test_write_unicode_bad(self):
+    def test_write_unicode_default_encoding(self):
         with TempDirectory() as d:
-            with ShouldRaise(TypeError("a bytes-like object is required, not 'str'")):
-                d.write('test.file', u'\xa3')
+            d.write('test.file', u'\xa3')
+            compare((d / 'test.file').read_text(), expected=u'\xa3')
 
     def test_just_empty_non_recursive(self):
         with TempDirectory() as d:
@@ -312,26 +310,22 @@ class TempDirectoryTests(TestCase):
         with TempDirectory(encoding='ascii') as d:
             compare(d.as_path(('foo', 'bar')), expected=Path(d.path) / 'foo' / 'bar', strict=True)
 
-    def test_as_local_minimal(self):
+    def test_traverse(self):
         with TempDirectory(encoding='ascii') as d:
-            compare(d.as_local(), expected=local(d.path), strict=True)
+            compare((d / 'foo' / 'bar'), expected=Path(d.path) / 'foo' / 'bar', strict=True)
 
-    def test_as_local_relative_string(self):
-        with TempDirectory(encoding='ascii') as d:
-            compare(d.as_local('foo/bar'), expected=local(d.path) / 'foo' / 'bar', strict=True)
-
-    def test_as_local_relative_sequence(self):
-        with TempDirectory(encoding='ascii') as d:
-            compare(d.as_local(('foo', 'bar')), expected=local(d.path) / 'foo' / 'bar', strict=True)
+    def test_cwd_context_manager(self):
+        original = os.getcwd()
+        try:
+            # need to resolve links thanks to /tmp location on macos!
+            with TempDirectory(cwd=True) as d:
+                compare(Path(os.getcwd()).resolve(), expected=Path(d.path).resolve())
+            compare(Path(os.getcwd()).resolve(), expected=Path(original).resolve())
+        finally:
+            os.chdir(original)
 
 
 def test_wrap_path(tmp_path: Path):
     with TempDirectory(tmp_path) as d:
         assert d.path == str(tmp_path)
     assert tmp_path.exists()
-
-
-def test_wrap_local(tmpdir: local):
-    with TempDirectory(tmpdir) as d:
-        assert d.path == str(tmpdir)
-    assert tmpdir.exists()
